import 'dart:io';

import 'package:archive/archive_io.dart';

/// Creates a zip archive of the given [directory].
Future<List<int>> zipDir(Directory directory) async {
  final archive = Archive();
  final files = directory.list(recursive: true);

  Future<void> addEntityToArchive(FileSystemEntity entity) async {
    if (entity is! File) return;

    final length = entity.length();
    final bytes = entity.readAsBytes();

    archive.addFile(
      ArchiveFile(
        // Store the files within a `project` directory.
        entity.path.replaceFirst('${directory.path}/', 'project/'),
        await length,
        await bytes,
      ),
    );
  }

  // Add all files to the archive in parallel.
  await Future.wait(await files.map(addEntityToArchive).toList());

  final encoded = TarEncoder().encode(archive);

  if (encoded.isEmpty) {
    throw Exception('Failed to encode archive.');
  }

  return encoded;
}
